# LTSpiceXVII Benchmark Script
# E. Sims 3/29/2020
# Udo Krebelder <udo.krebelder@gmx.at> 10/02/2022

$date = date
Write-Output 'LTSpice Benchmark'
Write-Output ''

Write-Output 'CPU Info...'
Get-WmiObject -Class Win32_Processor | Select-Object -Property Name, Number*

Start-Sleep -s 1

$env:Path = "C:\Program Files\LTC\LTspiceXVII;" + $env:Path
$env:Path = "C:\Program Files\LTspiceXVII;" + $env:Path

<#
*Write-Output ''
Write-Output 'running baseline benchmark...'

$baselinetime = 0
$numberofbaselineattemps = 0

for($i = 0; $i -lt $numberofbaselineattemps; $i++)
{
    $baselinetime += (Measure-Command {cmd /c 'XVIIx64.exe' -b -run .\NOT_A_REAL_FILE.asc}).TotalSeconds/$numberofbaselineattemps
    Start-Sleep -s 1
}
Write-Output ('average ltspice start time: ' + $baselinetime)
#>

Write-Output ''
Start-Sleep -s 1

$files = @('AzurAmp.asc', 'LT3845_TA01.asc', 'BuckBoost.asc', 'MonteCarlo.asc', 'SettleTime.asc', 'Electrometer.asc', 'OscillatorQuadrature.asc', 'AudioChannels16.asc')
$runs = @()
$totaltime = 0

foreach($file in $files)
{
    Write-Output ('Running ' + $file + ': ')
    $time = (Measure-Command {cmd /c 'XVIIx64.exe' -b -run $file}).TotalSeconds - $baselinetime
    $runs += [pscustomobject]@{'File'=$file;'ExecTime'=[math]::round($time,1)}
    $totaltime += $time
    Write-Output ('  ' + [math]::round($time,1) + ' seconds.')
    Write-Output ''
    Start-Sleep -s 1
    $a = (Get-Item $file).basename
    Remove-Item ($a + '.log')
    Remove-Item ($a + '.net')
    Remove-Item ($a + '.raw')
    $f = ($a + '.op.raw')
    if (Test-Path $f) { Remove-Item $f }
}

Write-Output ('Total time: ' + [math]::round($totaltime,1) + ' seconds')
Write-Output ''

$logfile = 'LTSpiceBenchmarkReport.txt'

if (!(Test-Path .\$logfile)) { New-Item -Path . -Name $logfile -ItemType "file" }

Add-Content -Path .\$logfile 'LTSpice Benchmark Report'
Add-Content -Path .\$logfile ($env:computername + ' ' + $date)

Get-WmiObject -Class Win32_Processor | Select-Object -Property Name, Number* | Out-File .\$logfile -Append -Encoding ASCII
#Add-Content -Path .\$logfile ('LTSpice avg startup time: ' + $baselinetime + ' seconds')
$runs | Select-Object -Property File, ExecTime | Out-File .\$logfile -Append -Encoding ASCII
Add-Content -Path .\$logfile ('Total time: ' + [math]::round($totaltime,1) + ' seconds')
Add-Content -Path .\$logfile ''
Add-Content -Path .\$logfile ''

#pause
